@@ -87,7 +87,17 @@ class DatabaseJobSource(object):
                 | Q(requested_device_type=device.device_type),
                 status=TestJob.SUBMITTED)
             jobs_for_device = jobs_for_device.extra(
-                select={'is_targeted': 'requested_device_id is not NULL'},
+                select={
+                    'is_targeted': 'requested_device_id is not NULL',
+                    'missing_tags': '''
+                        select count(*) from lava_scheduler_app_testjob_tags
+                                       where testjob_id = lava_scheduler_app_testjob.id
+                                       and tag_id not in (select tag_id
+                                                            from lava_scheduler_app_device_tags
+                                                           where device_id = '%s')
+                        ''' % device.hostname,
+                    },
+                where=['missing_tags = 0'],
                 order_by=['-is_targeted', 'submit_time'])
             jobs = jobs_for_device[:1]
             if jobs:
